==> ejc-zypms-impl-3.0.0-20250816.040327-140-sources.jar: com/ejianc/business/material/vo/ImportUseApplySubVO.java <==
package com.ejianc.business.material.vo;

import com.ejianc.business.utils.ComputeUtil;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * @Author mrsir_wxp
 * @Date 2020/6/1  用料申请子实体
 * @Description UseApplySubEntity
 */

public class ImportUseApplySubVO extends BaseVO {

    private static final long serialVersionUID = 2779265683203439571L;

    /**
     * 主表id
     */
    private Long pid;

    /**
     * 物资分类名称
     */
    private String materialTypeName;


    /**
     * 物资分类id
     */
    private Long materialTypeId;

    /**
     * 物资名称
     */
    private String materialName;

    /**
     * 物资id
     */
    private Long materialId;

    /**
     * 规格型号
     */
    private String model;

    /**
     * 计量单位
     */
    private String unit;

    /**
     * 申请数量
     */
    private BigDecimal applyNum;

    /**
     * 暂估单价
     */
    private BigDecimal estimatePrice;

    /**
     * 暂估金额
     */
    private BigDecimal estimateMoney;

    /**
     * 计划进场日期
     */
    private String subPlanEnterDate;

    /**
     * 备注
     */
    private String memo;

    /**
     * 物资来源类型：1-总计划，2-物资档案，3-批次计划，4-导入
     */
    private String sourceType;

    /**
     * 物资来源单据Id
     */
    private Long sourceId;

    /**
     * 临时字段 计划进场日期字符串，导出使用
     */
    private String subPlanEnterDateStr;

    private String materialInfo; // 采购物资名称
    private Long supplierId; // 供应商品牌id
    private String supplierName; // 供应商品牌
    private Long modelId; // 规格型号id
    private String thickness; // 厚度
    private String colour; // 色号/容重

    private BigDecimal orderNum; // 订货量
    private BigDecimal planNum; // 进度量
    private BigDecimal totalNum; // 总量
    private Integer isFinish; // 是否完成1是0否

    private BigDecimal sumApplyNum; // 累计申请量

    private String orderPlanNum; // 订货量/进度量

    private String orderTotalNum; // 订货量/总量

    private BigDecimal masterPlanNum; // 总计划量
    private String orderMasterPlanNum; // 订货量/总计划量

    //唯一的key需要使用方自己构建
    public String onlyKey;
    //匹配状态
    public String matchStatus;
    //匹配数量
    public String matchNumber;
    //描述
    public String matchStatusDescription;

    /**
     * 导入失败原因
     */
    private String errorMessage;


    /**
     * 物资编码
     */
    private String materialCode;

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public BigDecimal getMasterPlanNum() {
        return masterPlanNum;
    }

    public void setMasterPlanNum(BigDecimal masterPlanNum) {
        this.masterPlanNum = masterPlanNum;
    }

    public String getOrderMasterPlanNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.masterPlanNum);
    }

    public void setOrderMasterPlanNum(String orderMasterPlanNum) {
        this.orderMasterPlanNum = orderMasterPlanNum;
    }

    public String getOrderPlanNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.planNum);
    }

    public void setOrderPlanNum(String orderPlanNum) {
        this.orderPlanNum = orderPlanNum;
    }

    public String getOrderTotalNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.totalNum);
    }

    public void setOrderTotalNum(String orderTotalNum) {
        this.orderTotalNum = orderTotalNum;
    }

    public BigDecimal getSumApplyNum() {
        return sumApplyNum;
    }

    public void setSumApplyNum(BigDecimal sumApplyNum) {
        this.sumApplyNum = sumApplyNum;
    }


    public String getMaterialInfo() {
        return materialInfo;
    }

    public void setMaterialInfo(String materialInfo) {
        this.materialInfo = materialInfo;
    }

    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }
    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }


    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    @ReferDeserialTransfer@ReferSerialTransfer(referCode = "support-defdoc")
    public Long getModelId() {
        return modelId;
    }
    @ReferDeserialTransfer
    public void setModelId(Long modelId) {
        this.modelId = modelId;
    }

    public String getThickness() {
        return thickness;
    }

    public void setThickness(String thickness) {
        this.thickness = thickness;
    }

    public String getColour() {
        return colour;
    }

    public void setColour(String colour) {
        this.colour = colour;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(BigDecimal totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getIsFinish() {
        return isFinish;
    }

    public void setIsFinish(Integer isFinish) {
        this.isFinish = isFinish;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getModel() {
        return model;
    }

    public void setModel(String model) {
        this.model = model;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getApplyNum() {
        return applyNum;
    }

    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }

    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }

    public BigDecimal getEstimateMoney() {
        return estimateMoney;
    }

    public void setEstimateMoney(BigDecimal estimateMoney) {
        this.estimateMoney = estimateMoney;
    }

    public String getSubPlanEnterDate() {
        return subPlanEnterDate;
    }

    public void setSubPlanEnterDate(String subPlanEnterDate) {
        this.subPlanEnterDate = subPlanEnterDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getSubPlanEnterDateStr() {
        return subPlanEnterDateStr;
    }

    public void setSubPlanEnterDateStr(String subPlanEnterDateStr) {
        this.subPlanEnterDateStr = subPlanEnterDateStr;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getOnlyKey() {
        return onlyKey;
    }

    public void setOnlyKey(String onlyKey) {
        this.onlyKey = onlyKey;
    }

    public String getMatchStatus() {
        return matchStatus;
    }

    public void setMatchStatus(String matchStatus) {
        this.matchStatus = matchStatus;
    }

    public String getMatchNumber() {
        return matchNumber;
    }

    public void setMatchNumber(String matchNumber) {
        this.matchNumber = matchNumber;
    }

    public String getMatchStatusDescription() {
        return matchStatusDescription;
    }

    public void setMatchStatusDescription(String matchStatusDescription) {
        this.matchStatusDescription = matchStatusDescription;
    }
}

==> ejc-zypms-impl-3.0.0-20251211.111337-165-sources.jar: com/ejianc/business/material/vo/ImportUseApplySubVO.java <==
package com.ejianc.business.material.vo;

import com.ejianc.business.utils.ComputeUtil;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;

/**
 * @Author mrsir_wxp
 * @Date 2020/6/1  用料申请子实体
 * @Description UseApplySubEntity
 */

public class ImportUseApplySubVO extends BaseVO {

    private static final long serialVersionUID = 2779265683203439571L;

    /**
     * 主表id
     */
    private Long pid;

    /**
     * 物资分类名称
     */
    private String materialTypeName;


    /**
     * 物资分类id
     */
    private Long materialTypeId;

    /**
     * 物资名称
     */
    private String materialName;

    /**
     * 物资id
     */
    private Long materialId;

    /**
     * 规格型号
     */
    private String modelName;

    /**
     * 计量单位
     */
    private String unit;

    /**
     * 申请数量
     */
    private BigDecimal applyNum;

    /**
     * 暂估单价
     */
    private BigDecimal estimatePrice;

    /**
     * 暂估金额
     */
    private BigDecimal estimateMoney;

    /**
     * 计划进场日期
     */
    private String subPlanEnterDate;

    /**
     * 备注
     */
    private String memo;

    /**
     * 物资来源类型：1-总计划，2-物资档案，3-批次计划，4-导入
     */
    private String sourceType;

    /**
     * 物资来源单据Id
     */
    private Long sourceId;

    /**
     * 临时字段 计划进场日期字符串，导出使用
     */
    private String subPlanEnterDateStr;

    private String materialInfo; // 采购物资名称
    private Long supplierId; // 供应商品牌id
    private String supplierName; // 供应商品牌
    private Long modelId; // 规格型号id
    private String thickness; // 厚度
    private String colour; // 色号/容重

    private BigDecimal orderNum; // 订货量
    private BigDecimal planNum; // 进度量
    private BigDecimal totalNum; // 总量
    private Integer isFinish; // 是否完成1是0否

    private BigDecimal sumApplyNum; // 累计申请量

    private String orderPlanNum; // 订货量/进度量

    private String orderTotalNum; // 订货量/总量

    private BigDecimal masterPlanNum; // 总计划量
    private String orderMasterPlanNum; // 订货量/总计划量

    //唯一的key需要使用方自己构建
    public String onlyKey;
    //匹配状态
    public String matchStatus;
    //匹配数量
    public String matchNumber;
    //描述
    public String matchStatusDescription;

    /**
     * 导入失败原因
     */
    private String errorMessage;


    /**
     * 物资编码
     */
    private String materialCode;

    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }

    public BigDecimal getMasterPlanNum() {
        return masterPlanNum;
    }

    public void setMasterPlanNum(BigDecimal masterPlanNum) {
        this.masterPlanNum = masterPlanNum;
    }

    public String getOrderMasterPlanNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.masterPlanNum);
    }

    public void setOrderMasterPlanNum(String orderMasterPlanNum) {
        this.orderMasterPlanNum = orderMasterPlanNum;
    }

    public String getOrderPlanNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.planNum);
    }

    public void setOrderPlanNum(String orderPlanNum) {
        this.orderPlanNum = orderPlanNum;
    }

    public String getOrderTotalNum() {
        return ComputeUtil.nullToZero(this.orderNum) + "/" + ComputeUtil.nullToZero(this.totalNum);
    }

    public void setOrderTotalNum(String orderTotalNum) {
        this.orderTotalNum = orderTotalNum;
    }

    public BigDecimal getSumApplyNum() {
        return sumApplyNum;
    }

    public void setSumApplyNum(BigDecimal sumApplyNum) {
        this.sumApplyNum = sumApplyNum;
    }


    public String getMaterialInfo() {
        return materialInfo;
    }

    public void setMaterialInfo(String materialInfo) {
        this.materialInfo = materialInfo;
    }

    @ReferSerialTransfer(referCode="support-supplier")
    public Long getSupplierId() {
        return supplierId;
    }
    @ReferDeserialTransfer
    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }


    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    @ReferDeserialTransfer@ReferSerialTransfer(referCode = "support-defdoc")
    public Long getModelId() {
        return modelId;
    }
    @ReferDeserialTransfer
    public void setModelId(Long modelId) {
        this.modelId = modelId;
    }

    public String getThickness() {
        return thickness;
    }

    public void setThickness(String thickness) {
        this.thickness = thickness;
    }

    public String getColour() {
        return colour;
    }

    public void setColour(String colour) {
        this.colour = colour;
    }

    public BigDecimal getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(BigDecimal orderNum) {
        this.orderNum = orderNum;
    }

    public BigDecimal getPlanNum() {
        return planNum;
    }

    public void setPlanNum(BigDecimal planNum) {
        this.planNum = planNum;
    }

    public BigDecimal getTotalNum() {
        return totalNum;
    }

    public void setTotalNum(BigDecimal totalNum) {
        this.totalNum = totalNum;
    }

    public Integer getIsFinish() {
        return isFinish;
    }

    public void setIsFinish(Integer isFinish) {
        this.isFinish = isFinish;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }

    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getModelName() {
        return modelName;
    }

    public void setModelName(String modelName) {
        this.modelName = modelName;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

    public BigDecimal getApplyNum() {
        return applyNum;
    }

    public void setApplyNum(BigDecimal applyNum) {
        this.applyNum = applyNum;
    }

    public BigDecimal getEstimatePrice() {
        return estimatePrice;
    }

    public void setEstimatePrice(BigDecimal estimatePrice) {
        this.estimatePrice = estimatePrice;
    }

    public BigDecimal getEstimateMoney() {
        return estimateMoney;
    }

    public void setEstimateMoney(BigDecimal estimateMoney) {
        this.estimateMoney = estimateMoney;
    }

    public String getSubPlanEnterDate() {
        return subPlanEnterDate;
    }

    public void setSubPlanEnterDate(String subPlanEnterDate) {
        this.subPlanEnterDate = subPlanEnterDate;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getSourceType() {
        return sourceType;
    }

    public void setSourceType(String sourceType) {
        this.sourceType = sourceType;
    }

    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }

    public String getSubPlanEnterDateStr() {
        return subPlanEnterDateStr;
    }

    public void setSubPlanEnterDateStr(String subPlanEnterDateStr) {
        this.subPlanEnterDateStr = subPlanEnterDateStr;
    }

    public String getErrorMessage() {
        return errorMessage;
    }

    public void setErrorMessage(String errorMessage) {
        this.errorMessage = errorMessage;
    }

    public String getOnlyKey() {
        return onlyKey;
    }

    public void setOnlyKey(String onlyKey) {
        this.onlyKey = onlyKey;
    }

    public String getMatchStatus() {
        return matchStatus;
    }

    public void setMatchStatus(String matchStatus) {
        this.matchStatus = matchStatus;
    }

    public String getMatchNumber() {
        return matchNumber;
    }

    public void setMatchNumber(String matchNumber) {
        this.matchNumber = matchNumber;
    }

    public String getMatchStatusDescription() {
        return matchStatusDescription;
    }

    public void setMatchStatusDescription(String matchStatusDescription) {
        this.matchStatusDescription = matchStatusDescription;
    }
}
